"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.list_users = void 0;
const zod_1 = require("zod");
const tool_js_1 = require("../../tool.js");
const util_js_1 = require("../../util.js");
const auth_js_1 = require("../../../gcp/auth.js");
exports.list_users = (0, tool_js_1.tool)({
    name: "list_users",
    description: "Retrieves all users in the project up to the specified limit.",
    inputSchema: zod_1.z.object({
        limit: zod_1.z
            .number()
            .optional()
            .default(100)
            .describe("The number of users to return. Defaults to 100 if not supplied."),
    }),
    annotations: {
        title: "List Firebase Users",
        readOnlyHint: true,
    },
    _meta: {
        requiresAuth: true,
        requiresProject: true,
    },
}, async ({ limit } = {}, { projectId }) => {
    if (!limit) {
        limit = 100;
    }
    const users = await (0, auth_js_1.listUsers)(projectId, limit);
    const usersPruned = users.map((user) => {
        const { passwordHash, salt, ...prunedUser } = user;
        return prunedUser;
    });
    return (0, util_js_1.toContent)(usersPruned);
});
